@@ -1,7 +1,7 @@
 # -*-coding: utf-8-*-
 from __future__ import division
 
-__version__ = '0.10.2'
+__version__ = '0.10.3'
 __revision__ = None
 __version_info__ = tuple([int(num) for num in __version__.split('.')])
 
@@ -15,7 +15,8 @@ import logging
 from sdata.metadata import Metadata, Attribute
 from sdata.data import Data, Schema
 from sdata.blob import Blob
-import sdata.timestamp as timestamp
+# import sdata.timestamp as timestamp
+from sdata.timestamp import today_str
 import inspect
 
 if sys.version_info < (3, 6):
@@ -30,6 +31,8 @@ except:
 def uuid_from_str(name):
     return uuid.uuid3(uuid.NAMESPACE_DNS, name)
 
+
+
 SDATACLS = {"Data": Data,
             "Blob": Blob,
             "Schema": Schema,
